spannertools.get_spanners_contained_by_components
=================================================

.. autofunction:: abjad.tools.spannertools.get_spanners_contained_by_components.get_spanners_contained_by_components
